@@ -5,20 +5,35 @@ package processor
 import (
 	"cmp"
 	"errors"
-	"fmt"
 	"slices"
 	"strings"
 )
 
+var (
+	errMissingShebang              = errors.New("missing shebang")
+	errUnknownShebang              = errors.New("unknown shebang")
+	errUnableToDetermineShebangCmd = errors.New("unable to determine shebang command")
+)
+
 // DetectLanguage detects a language based on the filename returns the language extension and error
 func DetectLanguage(name string) ([]string, string) {
 	extension := ""
 
-	t := strings.Count(name, ".")
+	if len(AllowListExtensions) == 0 {
+		// Check the full name for special languages such as xmake.lua, meson.build, ...
+		lang, ok := FilenameToLanguage[strings.ToLower(name)]
+		if ok {
+			return []string{lang}, name
+		}
 
-	// If there is no . in the filename or it starts with one then check if #! or other
-	if (t == 0 || (name[0] == '.' && t == 1)) && len(AllowListExtensions) == 0 {
-		return checkFullName(name)
+		t := strings.Count(name, ".")
+		// If there is no . in the filename or it starts with one then check if #!
+		if t == 0 || (name[0] == '.' && t == 1) {
+			printWarnF("possible #! file: %s", name)
+
+			// No extension indicates possible #! so mark as such for processing
+			return []string{SheBang}, name
+		}
 	}
 
 	// Lookup in case the full name matches
@@ -39,25 +54,10 @@ func DetectLanguage(name string) ([]string, string) {
 	return language, extension
 }
 
-func checkFullName(name string) ([]string, string) {
-	// Need to check if special type
-	language, ok := FilenameToLanguage[strings.ToLower(name)]
-	if ok {
-		return []string{language}, name
-	}
-
-	if Verbose {
-		printWarn(fmt.Sprintf("possible #! file: %s", name))
-	}
-
-	// No extension indicates possible #! so mark as such for processing
-	return []string{SheBang}, name
-}
-
 // DetectSheBang given some content attempt to determine if it has a #! that maps to a known language and return the language
 func DetectSheBang(content string) (string, error) {
 	if !strings.HasPrefix(content, "#!") {
-		return "", errors.New("Missing #!")
+		return "", errMissingShebang
 	}
 
 	index := strings.Index(content, "\n")
@@ -79,7 +79,7 @@ func DetectSheBang(content string) (string, error) {
 		}
 	}
 
-	return "", errors.New("Unknown #!")
+	return "", errUnknownShebang
 }
 
 func scanForSheBang(content []byte) (string, error) {
@@ -140,7 +140,7 @@ loop:
 		return candidate1, nil
 	}
 
-	return "", errors.New("Unable to determine #! command")
+	return "", errUnableToDetermineShebangCmd
 }
 
 type languageGuess struct {
@@ -221,13 +221,8 @@ func DetermineLanguage(filename string, fallbackLanguage string, possibleLanguag
 		}
 	}
 
-	if Verbose {
-		printWarn(fmt.Sprintf("guessing language %s for file %s", toSort[0].Name, filename))
-	}
-
-	if Trace {
-		printTrace(fmt.Sprintf("nanoseconds to guess language: %s: %d", filename, makeTimestampNano()-startTime))
-	}
+	printWarnF("guessing language %s for file %s", toSort[0].Name, filename)
+	printTraceF("nanoseconds to guess language: %s: %d", filename, makeTimestampNano()-startTime)
 
 	if len(toSort) != 0 {
 		return toSort[0].Name
