@@ -27,23 +27,24 @@ import (
 var tabularShortBreak = "───────────────────────────────────────────────────────────────────────────────\n"
 var tabularShortBreakCi = "-------------------------------------------------------------------------------\n"
 
-var tabularShortFormatHead = "%-20s %9s %9s %8s %9s %8s %10s\n"
-var tabularShortFormatBody = "%-20s %9d %9d %8d %9d %8d %10d\n"
-var tabularShortFormatFile = "%s %9d %8d %9d %8d %10d\n"
-var tabularShortFormatFileMaxMean = "MaxLine / MeanLine %11d %9d\n"
-var shortFormatFileTruncate = 29
-var shortNameTruncate = 20
-var tabularShortUlocLanguageFormatBody = "(ULOC) %33d\n"
-var tabularShortPercentLanguageFormatBody = "Percentage %18.1f%% %8.1f%% %7.1f%% %8.1f%% %7.1f%% %9.1f%%\n"
-var tabularShortUlocGlobalFormatBody = "Unique Lines of Code (ULOC) %12d\n"
+var tabularShortFormatHead = "%-15s %9s %11s %9s %9s %10s %10s\n"
+var tabularShortFormatBody = "%-15s %9d %11d %9d %9d %10d %10d\n"
+var tabularShortFormatFile = "%s %9d %9d %9d %10d %10d\n"
+var tabularShortFormatFileMaxMean = "MaxLine / MeanLine %6d %11d\n"
+var shortFormatFileTruncate = 26
+var shortNameTruncate = 15
+var tabularShortUlocLanguageFormatBody = "(ULOC) %30d\n"
+var tabularShortPercentLanguageFormatBody = "Percentage %13.1f%% %10.1f%% %8.1f%% %8.1f%% %9.1f%% %9.1f%%\n"
+var tabularShortUlocGlobalFormatBody = "Unique Lines of Code (ULOC) %9d\n"
+var tabularShortDrynessFormatBody = "DRYness %% %27.2f\n"
 
-var tabularShortFormatHeadNoComplexity = "%-22s %11s %11s %10s %11s %9s\n"
-var tabularShortFormatBodyNoComplexity = "%-22s %11d %11d %10d %11d %9d\n"
-var tabularShortFormatFileNoComplexity = "%s %11d %10d %11d %9d\n"
-var tabularShortFormatFileMaxMeanNoComplexity = "MaxLine / MeanLine %15d %11d\n"
+var tabularShortFormatHeadNoComplexity = "%-21s %11s %11s %10s %11s %10s\n"
+var tabularShortFormatBodyNoComplexity = "%-21s %11d %11d %10d %11d %10d\n"
+var tabularShortFormatFileNoComplexity = "%s %10d %10d %11d %10d\n"
+var tabularShortFormatFileMaxMeanNoComplexity = "MaxLine / MeanLine %14d %11d\n"
 var longNameTruncate = 22
-var tabularShortUlocLanguageFormatBodyNoComplexity = "(ULOC) %39d\n"
-var tabularShortPercentLanguageFormatBodyNoComplexity = "Percentage %22.1f%% %10.1f%% %9.1f%% %10.1f%% %8.1f%%\n"
+var tabularShortUlocLanguageFormatBodyNoComplexity = "(ULOC) %38d\n"
+var tabularShortPercentLanguageFormatBodyNoComplexity = "Percentage %21.1f%% %10.1f%% %9.1f%% %10.1f%% %9.1f%%\n"
 
 var tabularWideBreak = "─────────────────────────────────────────────────────────────────────────────────────────────────────────────\n"
 var tabularWideBreakCi = "-------------------------------------------------------------------------------------------------------------\n"
@@ -55,6 +56,7 @@ var wideFormatFileTruncate = 42
 var tabularWideUlocLanguageFormatBody = "(ULOC) %46d\n"
 var tabularWideUlocGlobalFormatBody = "Unique Lines of Code (ULOC) %25d\n"
 var tabularWideFormatBodyPercent = "Percentage %31.1f%% %8.1f%% %7.1f%% %8.1f%% %7.1f%% %9.1f%%\n"
+var tabularWideDrynessFormatBody = "DRYness %% %43.2f\n"
 
 var openMetricsMetadata = `# TYPE scc_files gauge
 # HELP scc_files Number of sourcecode files.
@@ -232,9 +234,7 @@ func toClocYAML(input chan *FileJob) string {
 	languageYaml, _ := yaml.Marshal(langs)
 	yamlString := "# https://github.com/boyter/scc/\n" + string(reportYaml) + string(languageYaml) + string(sumYaml)
 
-	if Debug {
-		printDebug(fmt.Sprintf("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime))
-	}
+	printDebugF("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime)
 
 	return yamlString
 }
@@ -247,9 +247,7 @@ func toJSON(input chan *FileJob) string {
 	json := jsoniter.ConfigCompatibleWithStandardLibrary
 	jsonString, _ := json.Marshal(language)
 
-	if Debug {
-		printDebug(fmt.Sprintf("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime))
-	}
+	printDebugF("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime)
 
 	return string(jsonString)
 }
@@ -281,9 +279,7 @@ func toJSON2(input chan *FileJob) string {
 		EstimatedPeople:         people,
 	})
 
-	if Debug {
-		printDebug(fmt.Sprintf("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime))
-	}
+	printDebugF("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime)
 
 	return string(jsonString)
 }
@@ -300,25 +296,7 @@ func toCSVSummary(input chan *FileJob) string {
 	language := aggregateLanguageSummary(input)
 	language = sortLanguageSummary(language)
 
-	records := make([][]string, 0, len(language))
-
-	for _, result := range language {
-		records = append(records, []string{
-			result.Name,
-			strconv.FormatInt(result.Lines, 10),
-			strconv.FormatInt(result.Code, 10),
-			strconv.FormatInt(result.Comment, 10),
-			strconv.FormatInt(result.Blank, 10),
-			strconv.FormatInt(result.Complexity, 10),
-			strconv.FormatInt(result.Bytes, 10),
-			strconv.FormatInt(result.Count, 10),
-			strconv.Itoa(len(ulocLanguageCount[result.Name])),
-		})
-	}
-
-	slices.SortFunc(records, getRecordsSortFunc())
-
-	recordsEnd := [][]string{{
+	record := []string{
 		"Language",
 		"Lines",
 		"Code",
@@ -328,22 +306,34 @@ func toCSVSummary(input chan *FileJob) string {
 		"Bytes",
 		"Files",
 		"ULOC",
-	}}
-
-	recordsEnd = append(recordsEnd, records...)
+	}
 
 	b := &bytes.Buffer{}
 	w := csv.NewWriter(b)
-	_ = w.WriteAll(recordsEnd)
+	_ = w.Write(record)
+
+	for _, result := range language {
+		record[0] = result.Name
+		record[1] = strconv.FormatInt(result.Lines, 10)
+		record[2] = strconv.FormatInt(result.Code, 10)
+		record[3] = strconv.FormatInt(result.Comment, 10)
+		record[4] = strconv.FormatInt(result.Blank, 10)
+		record[5] = strconv.FormatInt(result.Complexity, 10)
+		record[6] = strconv.FormatInt(result.Bytes, 10)
+		record[7] = strconv.FormatInt(result.Count, 10)
+		record[8] = strconv.Itoa(len(ulocLanguageCount[result.Name]))
+		_ = w.Write(record)
+	}
+
 	w.Flush()
 
 	return b.String()
 }
 
-func getRecordsSortFunc() func(a, b []string) int {
+func getCSVFilesSortFunc(sortBy string) func(a, b []string) int {
 	// Cater for the common case of adding plural even for those options that don't make sense
 	// as it's quite common for those who English is not a first language to make a simple mistake
-	switch SortBy {
+	switch sortBy {
 	case "name", "names":
 		return func(a, b []string) int {
 			return strings.Compare(a[2], b[2])
@@ -413,7 +403,7 @@ func toCSVFiles(input chan *FileJob) string {
 		})
 	}
 
-	slices.SortFunc(records, getRecordsSortFunc())
+	slices.SortFunc(records, getCSVFilesSortFunc(SortBy))
 
 	recordsEnd := [][]string{{
 		"Language",
@@ -453,13 +443,13 @@ func toOpenMetricsSummary(input chan *FileJob) string {
 	sb := &strings.Builder{}
 	sb.WriteString(openMetricsMetadata)
 	for _, result := range language {
-		fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "files", result.Name, result.Count)
-		fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "lines", result.Name, result.Lines)
-		fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "code", result.Name, result.Code)
-		fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "comments", result.Name, result.Comment)
-		fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "blanks", result.Name, result.Blank)
-		fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "complexity", result.Name, result.Complexity)
-		fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "bytes", result.Name, result.Bytes)
+		_, _ = fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "files", result.Name, result.Count)
+		_, _ = fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "lines", result.Name, result.Lines)
+		_, _ = fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "code", result.Name, result.Code)
+		_, _ = fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "comments", result.Name, result.Comment)
+		_, _ = fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "blanks", result.Name, result.Blank)
+		_, _ = fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "complexity", result.Name, result.Complexity)
+		_, _ = fmt.Fprintf(sb, openMetricsSummaryRecordFormat, "bytes", result.Name, result.Bytes)
 	}
 	return sb.String()
 }
@@ -469,12 +459,12 @@ func toOpenMetricsFiles(input chan *FileJob) string {
 	sb.WriteString(openMetricsMetadata)
 	for file := range input {
 		var filename = strings.ReplaceAll(file.Location, "\\", "\\\\")
-		fmt.Fprintf(sb, openMetricsFileRecordFormat, "lines", file.Language, filename, file.Lines)
-		fmt.Fprintf(sb, openMetricsFileRecordFormat, "code", file.Language, filename, file.Code)
-		fmt.Fprintf(sb, openMetricsFileRecordFormat, "comments", file.Language, filename, file.Comment)
-		fmt.Fprintf(sb, openMetricsFileRecordFormat, "blanks", file.Language, filename, file.Blank)
-		fmt.Fprintf(sb, openMetricsFileRecordFormat, "complexity", file.Language, filename, file.Complexity)
-		fmt.Fprintf(sb, openMetricsFileRecordFormat, "bytes", file.Language, filename, file.Bytes)
+		_, _ = fmt.Fprintf(sb, openMetricsFileRecordFormat, "lines", file.Language, filename, file.Lines)
+		_, _ = fmt.Fprintf(sb, openMetricsFileRecordFormat, "code", file.Language, filename, file.Code)
+		_, _ = fmt.Fprintf(sb, openMetricsFileRecordFormat, "comments", file.Language, filename, file.Comment)
+		_, _ = fmt.Fprintf(sb, openMetricsFileRecordFormat, "blanks", file.Language, filename, file.Blank)
+		_, _ = fmt.Fprintf(sb, openMetricsFileRecordFormat, "complexity", file.Language, filename, file.Complexity)
+		_, _ = fmt.Fprintf(sb, openMetricsFileRecordFormat, "bytes", file.Language, filename, file.Bytes)
 	}
 	sb.WriteString("# EOF\n")
 	return sb.String()
@@ -852,7 +842,7 @@ func fileSummarizeLong(input chan *FileJob) string {
 	str := &strings.Builder{}
 
 	str.WriteString(getTabularWideBreak())
-	fmt.Fprintf(str, tabularWideFormatHead, "Language", "Files", "Lines", "Blanks", "Comments", "Code", "Complexity", "Complexity/Lines")
+	_, _ = fmt.Fprintf(str, tabularWideFormatHead, "Language", "Files", "Lines", "Blanks", "Comments", "Code", "Complexity", "Complexity/Lines")
 
 	if !Files {
 		str.WriteString(getTabularWideBreak())
@@ -934,10 +924,10 @@ func fileSummarizeLong(input chan *FileJob) string {
 			trimmedName = summary.Name[:longNameTruncate-1] + "…"
 		}
 
-		fmt.Fprintf(str, tabularWideFormatBody, trimmedName, summary.Count, summary.Lines, summary.Blank, summary.Comment, summary.Code, summary.Complexity, summary.WeightedComplexity)
+		_, _ = fmt.Fprintf(str, tabularWideFormatBody, trimmedName, summary.Count, summary.Lines, summary.Blank, summary.Comment, summary.Code, summary.Complexity, summary.WeightedComplexity)
 
 		if Percent {
-			fmt.Fprintf(str,
+			_, _ = fmt.Fprintf(str,
 				tabularWideFormatBodyPercent,
 				float64(len(summary.Files))/float64(sumFiles)*100,
 				float64(summary.Lines)/float64(sumLines)*100,
@@ -955,11 +945,11 @@ func fileSummarizeLong(input chan *FileJob) string {
 		}
 
 		if MaxMean {
-			fmt.Fprintf(str, tabularWideFormatFileMaxMean, maxIn(summary.LineLength), meanIn(summary.LineLength))
+			_, _ = fmt.Fprintf(str, tabularWideFormatFileMaxMean, maxIn(summary.LineLength), meanIn(summary.LineLength))
 		}
 
 		if UlocMode {
-			fmt.Fprintf(str, tabularWideUlocLanguageFormatBody, len(ulocLanguageCount[summary.Name]))
+			_, _ = fmt.Fprintf(str, tabularWideUlocLanguageFormatBody, len(ulocLanguageCount[summary.Name]))
 			if !Files && summary.Name != language[len(language)-1].Name {
 				str.WriteString(tabularWideBreakCi)
 			}
@@ -973,24 +963,22 @@ func fileSummarizeLong(input chan *FileJob) string {
 				tmp := unicodeAwareTrim(res.Location, wideFormatFileTruncate)
 				tmp = unicodeAwareRightPad(tmp, 43)
 
-				fmt.Fprintf(str, tabularWideFormatFile, tmp, res.Lines, res.Blank, res.Comment, res.Code, res.Complexity, res.WeightedComplexity)
+				_, _ = fmt.Fprintf(str, tabularWideFormatFile, tmp, res.Lines, res.Blank, res.Comment, res.Code, res.Complexity, res.WeightedComplexity)
 			}
 		}
 	}
 
-	if Debug {
-		printDebug(fmt.Sprintf("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime))
-	}
+	printDebugF("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime)
 
 	str.WriteString(getTabularWideBreak())
-	fmt.Fprintf(str, tabularWideFormatBody, "Total", sumFiles, sumLines, sumBlank, sumComment, sumCode, sumComplexity, sumWeightedComplexity)
+	_, _ = fmt.Fprintf(str, tabularWideFormatBody, "Total", sumFiles, sumLines, sumBlank, sumComment, sumCode, sumComplexity, sumWeightedComplexity)
 	str.WriteString(getTabularWideBreak())
 
 	if UlocMode {
-		fmt.Fprintf(str, tabularWideUlocGlobalFormatBody, len(ulocGlobalCount))
+		_, _ = fmt.Fprintf(str, tabularWideUlocGlobalFormatBody, len(ulocGlobalCount))
 		if Dryness {
 			dryness := float64(len(ulocGlobalCount)) / float64(sumLines)
-			fmt.Fprintf(str, "DRYness %% %43.2f\n", dryness)
+			_, _ = fmt.Fprintf(str, tabularWideDrynessFormatBody, dryness)
 		}
 		str.WriteString(getTabularWideBreak())
 	}
@@ -1044,9 +1032,9 @@ func fileSummarizeShort(input chan *FileJob) string {
 
 	str.WriteString(getTabularShortBreak())
 	if !Complexity {
-		fmt.Fprintf(str, tabularShortFormatHead, "Language", "Files", "Lines", "Blanks", "Comments", "Code", "Complexity")
+		_, _ = fmt.Fprintf(str, tabularShortFormatHead, "Language", "Files", "Lines", "Blanks", "Comments", "Code", "Complexity")
 	} else {
-		fmt.Fprintf(str, tabularShortFormatHeadNoComplexity, "Language", "Files", "Lines", "Blanks", "Comments", "Code")
+		_, _ = fmt.Fprintf(str, tabularShortFormatHeadNoComplexity, "Language", "Files", "Lines", "Blanks", "Comments", "Code")
 	}
 
 	if !Files {
@@ -1056,6 +1044,8 @@ func fileSummarizeShort(input chan *FileJob) string {
 	lang := map[string]LanguageSummary{}
 	var sumFiles, sumLines, sumCode, sumComment, sumBlank, sumComplexity, sumBytes int64 = 0, 0, 0, 0, 0, 0, 0
 
+	p := gmessage.NewPrinter(glanguage.Make(os.Getenv("LANG")))
+
 	for res := range input {
 		sumFiles++
 		sumLines += res.Lines
@@ -1119,14 +1109,14 @@ func fileSummarizeShort(input chan *FileJob) string {
 		trimmedName = trimNameShort(summary, trimmedName)
 
 		if !Complexity {
-			_, _ = fmt.Fprintf(str, tabularShortFormatBody, trimmedName, summary.Count, summary.Lines, summary.Blank, summary.Comment, summary.Code, summary.Complexity)
+			_, _ = p.Fprintf(str, tabularShortFormatBody, trimmedName, summary.Count, summary.Lines, summary.Blank, summary.Comment, summary.Code, summary.Complexity)
 		} else {
-			_, _ = fmt.Fprintf(str, tabularShortFormatBodyNoComplexity, trimmedName, summary.Count, summary.Lines, summary.Blank, summary.Comment, summary.Code)
+			_, _ = p.Fprintf(str, tabularShortFormatBodyNoComplexity, trimmedName, summary.Count, summary.Lines, summary.Blank, summary.Comment, summary.Code)
 		}
 
 		if Percent {
 			if !Complexity {
-				_, _ = fmt.Fprintf(str,
+				_, _ = p.Fprintf(str,
 					tabularShortPercentLanguageFormatBody,
 					float64(len(summary.Files))/float64(sumFiles)*100,
 					float64(summary.Lines)/float64(sumLines)*100,
@@ -1136,7 +1126,7 @@ func fileSummarizeShort(input chan *FileJob) string {
 					float64(summary.Complexity)/float64(sumComplexity)*100,
 				)
 			} else {
-				_, _ = fmt.Fprintf(str,
+				_, _ = p.Fprintf(str,
 					tabularShortPercentLanguageFormatBodyNoComplexity,
 					float64(len(summary.Files))/float64(sumFiles)*100,
 					float64(summary.Lines)/float64(sumLines)*100,
@@ -1151,9 +1141,9 @@ func fileSummarizeShort(input chan *FileJob) string {
 
 		if MaxMean {
 			if !Complexity {
-				_, _ = fmt.Fprintf(str, tabularShortFormatFileMaxMean, maxIn(summary.LineLength), meanIn(summary.LineLength))
+				_, _ = p.Fprintf(str, tabularShortFormatFileMaxMean, maxIn(summary.LineLength), meanIn(summary.LineLength))
 			} else {
-				_, _ = fmt.Fprintf(str, tabularShortFormatFileMaxMeanNoComplexity, maxIn(summary.LineLength), meanIn(summary.LineLength))
+				_, _ = p.Fprintf(str, tabularShortFormatFileMaxMeanNoComplexity, maxIn(summary.LineLength), meanIn(summary.LineLength))
 			}
 
 			addBreak = true
@@ -1167,20 +1157,20 @@ func fileSummarizeShort(input chan *FileJob) string {
 				tmp := unicodeAwareTrim(res.Location, shortFormatFileTruncate)
 
 				if !Complexity {
-					tmp = unicodeAwareRightPad(tmp, 30)
-					_, _ = fmt.Fprintf(str, tabularShortFormatFile, tmp, res.Lines, res.Blank, res.Comment, res.Code, res.Complexity)
+					tmp = unicodeAwareRightPad(tmp, 27)
+					_, _ = p.Fprintf(str, tabularShortFormatFile, tmp, res.Lines, res.Blank, res.Comment, res.Code, res.Complexity)
 				} else {
 					tmp = unicodeAwareRightPad(tmp, 34)
-					_, _ = fmt.Fprintf(str, tabularShortFormatFileNoComplexity, tmp, res.Lines, res.Blank, res.Comment, res.Code)
+					_, _ = p.Fprintf(str, tabularShortFormatFileNoComplexity, tmp, res.Lines, res.Blank, res.Comment, res.Code)
 				}
 			}
 		}
 
 		if UlocMode {
 			if !Complexity {
-				_, _ = fmt.Fprintf(str, tabularShortUlocLanguageFormatBody, len(ulocLanguageCount[summary.Name]))
+				_, _ = p.Fprintf(str, tabularShortUlocLanguageFormatBody, len(ulocLanguageCount[summary.Name]))
 			} else {
-				_, _ = fmt.Fprintf(str, tabularShortUlocLanguageFormatBodyNoComplexity, len(ulocLanguageCount[summary.Name]))
+				_, _ = p.Fprintf(str, tabularShortUlocLanguageFormatBodyNoComplexity, len(ulocLanguageCount[summary.Name]))
 			}
 
 			addBreak = true
@@ -1193,23 +1183,21 @@ func fileSummarizeShort(input chan *FileJob) string {
 		}
 	}
 
-	if Debug {
-		printDebug(fmt.Sprintf("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime))
-	}
+	printDebugF("milliseconds to build formatted string: %d", makeTimestampMilli()-startTime)
 
 	str.WriteString(getTabularShortBreak())
 	if !Complexity {
-		_, _ = fmt.Fprintf(str, tabularShortFormatBody, "Total", sumFiles, sumLines, sumBlank, sumComment, sumCode, sumComplexity)
+		_, _ = p.Fprintf(str, tabularShortFormatBody, "Total", sumFiles, sumLines, sumBlank, sumComment, sumCode, sumComplexity)
 	} else {
-		_, _ = fmt.Fprintf(str, tabularShortFormatBodyNoComplexity, "Total", sumFiles, sumLines, sumBlank, sumComment, sumCode)
+		_, _ = p.Fprintf(str, tabularShortFormatBodyNoComplexity, "Total", sumFiles, sumLines, sumBlank, sumComment, sumCode)
 	}
 	str.WriteString(getTabularShortBreak())
 
 	if UlocMode {
-		_, _ = fmt.Fprintf(str, tabularShortUlocGlobalFormatBody, len(ulocGlobalCount))
+		_, _ = p.Fprintf(str, tabularShortUlocGlobalFormatBody, len(ulocGlobalCount))
 		if Dryness {
 			dryness := float64(len(ulocGlobalCount)) / float64(sumLines)
-			_, _ = fmt.Fprintf(str, "DRYness %% %30.2f\n", dryness)
+			_, _ = p.Fprintf(str, tabularShortDrynessFormatBody, dryness)
 		}
 		str.WriteString(getTabularShortBreak())
 	}
@@ -1265,14 +1253,14 @@ func calculateCocomoSLOCCount(sumCode int64, str *strings.Builder) {
 
 	p := gmessage.NewPrinter(glanguage.Make(os.Getenv("LANG")))
 
-	p.Fprintf(str, "Total Physical Source Lines of Code (SLOC)                     = %d\n", sumCode)
-	p.Fprintf(str, "Development Effort Estimate, Person-Years (Person-Months)      = %.2f (%.2f)\n", estimatedEffort/12, estimatedEffort)
-	p.Fprintf(str, " (Basic COCOMO model, Person-Months = %.2f*(KSLOC**%.2f)*%.2f)\n", projectType[CocomoProjectType][0], projectType[CocomoProjectType][1], EAF)
-	p.Fprintf(str, "Schedule Estimate, Years (Months)                              = %.2f (%.2f)\n", estimatedScheduleMonths/12, estimatedScheduleMonths)
-	p.Fprintf(str, " (Basic COCOMO model, Months = %.2f*(person-months**%.2f))\n", projectType[CocomoProjectType][2], projectType[CocomoProjectType][3])
-	p.Fprintf(str, "Estimated Average Number of Developers (Effort/Schedule)       = %.2f\n", estimatedPeopleRequired)
-	p.Fprintf(str, "Total Estimated Cost to Develop                                = %s%.0f\n", CurrencySymbol, estimatedCost)
-	p.Fprintf(str, " (average salary = %s%d/year, overhead = %.2f)\n", CurrencySymbol, AverageWage, Overhead)
+	_, _ = p.Fprintf(str, "Total Physical Source Lines of Code (SLOC)                     = %d\n", sumCode)
+	_, _ = p.Fprintf(str, "Development Effort Estimate, Person-Years (Person-Months)      = %.2f (%.2f)\n", estimatedEffort/12, estimatedEffort)
+	_, _ = p.Fprintf(str, " (Basic COCOMO model, Person-Months = %.2f*(KSLOC**%.2f)*%.2f)\n", projectType[CocomoProjectType][0], projectType[CocomoProjectType][1], EAF)
+	_, _ = p.Fprintf(str, "Schedule Estimate, Years (Months)                              = %.2f (%.2f)\n", estimatedScheduleMonths/12, estimatedScheduleMonths)
+	_, _ = p.Fprintf(str, " (Basic COCOMO model, Months = %.2f*(person-months**%.2f))\n", projectType[CocomoProjectType][2], projectType[CocomoProjectType][3])
+	_, _ = p.Fprintf(str, "Estimated Average Number of Developers (Effort/Schedule)       = %.2f\n", estimatedPeopleRequired)
+	_, _ = p.Fprintf(str, "Total Estimated Cost to Develop                                = %s%.0f\n", CurrencySymbol, estimatedCost)
+	_, _ = p.Fprintf(str, " (average salary = %s%d/year, overhead = %.2f)\n", CurrencySymbol, AverageWage, Overhead)
 }
 
 func calculateCocomo(sumCode int64, str *strings.Builder) {
@@ -1280,12 +1268,12 @@ func calculateCocomo(sumCode int64, str *strings.Builder) {
 
 	p := gmessage.NewPrinter(glanguage.Make(os.Getenv("LANG")))
 
-	p.Fprintf(str, "Estimated Cost to Develop (%s) %s%d\n", CocomoProjectType, CurrencySymbol, int64(estimatedCost))
-	p.Fprintf(str, "Estimated Schedule Effort (%s) %.2f months\n", CocomoProjectType, estimatedScheduleMonths)
+	_, _ = p.Fprintf(str, "Estimated Cost to Develop (%s) %s%d\n", CocomoProjectType, CurrencySymbol, int64(estimatedCost))
+	_, _ = p.Fprintf(str, "Estimated Schedule Effort (%s) %.2f months\n", CocomoProjectType, estimatedScheduleMonths)
 	if math.IsNaN(estimatedPeopleRequired) {
-		p.Fprintf(str, "Estimated People Required 1 Grandparent\n")
+		_, _ = p.Fprintf(str, "Estimated People Required 1 Grandparent\n")
 	} else {
-		p.Fprintf(str, "Estimated People Required (%s) %.2f\n", CocomoProjectType, estimatedPeopleRequired)
+		_, _ = p.Fprintf(str, "Estimated People Required (%s) %.2f\n", CocomoProjectType, estimatedPeopleRequired)
 	}
 }
 
@@ -1316,7 +1304,7 @@ func calculateSize(sumBytes int64, str *strings.Builder) {
 		size = float64(sumBytes) / (1012 * 1012)
 	case "xkcd-imaginary":
 		str.WriteString("used in quantum computing\n")
-		fmt.Fprintf(str, "Processed %d bytes, %s megabytes (%s)\n", sumBytes, `¯\_(ツ)_/¯`, strings.ToUpper(SizeUnit))
+		_, _ = fmt.Fprintf(str, "Processed %d bytes, %s megabytes (%s)\n", sumBytes, `¯\_(ツ)_/¯`, strings.ToUpper(SizeUnit))
 	case "xkcd-intel":
 		str.WriteString("calculated on pentium F.P.U.\n")
 		size = float64(sumBytes) / (1023.937528 * 1023.937528)
@@ -1338,7 +1326,7 @@ func calculateSize(sumBytes int64, str *strings.Builder) {
 	}
 
 	if !strings.EqualFold(SizeUnit, "xkcd-imaginary") {
-		fmt.Fprintf(str, "Processed %d bytes, %.3f megabytes (%s)\n", sumBytes, size, strings.ToUpper(SizeUnit))
+		_, _ = fmt.Fprintf(str, "Processed %d bytes, %.3f megabytes (%s)\n", sumBytes, size, strings.ToUpper(SizeUnit))
 	}
 }
 
@@ -1454,6 +1442,20 @@ func sortLanguageSummary(language []LanguageSummary) []LanguageSummary {
 			}
 			return strings.Compare(a.Name, b.Name)
 		})
+	case "byte", "bytes":
+		slices.SortFunc(language, func(a, b LanguageSummary) int {
+			if order := cmp.Compare(b.Bytes, a.Bytes); order != 0 {
+				return order
+			}
+			return strings.Compare(a.Name, b.Name)
+		})
+	case "file", "files":
+		slices.SortFunc(language, func(a, b LanguageSummary) int {
+			if order := cmp.Compare(b.Count, a.Count); order != 0 {
+				return order
+			}
+			return strings.Compare(a.Name, b.Name)
+		})
 	default: // Files IE default falls into this category
 		slices.SortFunc(language, func(a, b LanguageSummary) int {
 			if order := cmp.Compare(b.Count, a.Count); order != 0 {
@@ -1465,55 +1467,3 @@ func sortLanguageSummary(language []LanguageSummary) []LanguageSummary {
 
 	return language
 }
-
-// Get the time as standard UTC/Zulu format
-func getFormattedTime() string {
-	return time.Now().UTC().Format(time.RFC3339)
-}
-
-// Prints a message to stdout if flag to enable warning output is set
-func printWarn(msg string) {
-	if Verbose {
-		fmt.Printf(" WARN %s: %s\n", getFormattedTime(), msg)
-	}
-}
-
-// Prints a message to stdout if flag to enable warning output is set
-func printWarnf(msg string, args ...interface{}) {
-	if Verbose {
-		printWarn(fmt.Sprintf(msg, args...))
-	}
-}
-
-// Prints a message to stdout if flag to enable debug output is set
-func printDebug(msg string) {
-	if Debug {
-		fmt.Printf("DEBUG %s: %s\n", getFormattedTime(), msg)
-	}
-}
-
-// Prints a message to stdout if flag to enable debug output is set
-func printDebugf(msg string, args ...interface{}) {
-	if Debug {
-		printDebug(fmt.Sprintf(msg, args...))
-	}
-}
-
-// Prints a message to stdout if flag to enable trace output is set
-func printTrace(msg string) {
-	if Trace {
-		fmt.Printf("TRACE %s: %s\n", getFormattedTime(), msg)
-	}
-}
-
-// Prints a message to stdout if flag to enable trace output is set
-func printTracef(msg string, args ...interface{}) {
-	if Trace {
-		printTrace(fmt.Sprintf(msg, args...))
-	}
-}
-
-// Used when explicitly for os.exit output when crashing out
-func printError(msg string) {
-	_, _ = fmt.Fprintf(os.Stderr, "ERROR %s: %s\n", getFormattedTime(), msg)
-}
