@@ -3,9 +3,6 @@
 package processor
 
 import (
-	"bytes"
-	"compress/gzip"
-	"encoding/base64"
 	"fmt"
 	"os"
 	"path/filepath"
@@ -18,12 +15,10 @@ import (
 	"sync"
 
 	"github.com/boyter/gocodewalker"
-
-	jsoniter "github.com/json-iterator/go"
 )
 
 // Version indicates the version of the application
-var Version = "3.5.0"
+var Version = "3.6.0"
 
 // Flags set via the CLI which control how the output is displayed
 
@@ -120,7 +115,7 @@ var UlocMode = false
 // Percent toggles checking for binary files using NUL bytes
 var Percent = false
 
-// MaxMean toggles checking for binary files using NUL bytes
+// MaxMean sets the calculation of the max and mean line length
 var MaxMean = false
 
 // Dryness toggles checking for binary files using NUL bytes
@@ -209,9 +204,6 @@ var LargeByteCount int64 = 1000000
 // DirFilePaths is not set via flags but by arguments following the flags for file or directory to process
 var DirFilePaths = []string{}
 
-// Raw languageDatabase loaded
-var languageDatabase = map[string]Language{}
-
 // ExtensionToLanguage is loaded from the JSON that is in constants.go
 var ExtensionToLanguage = map[string][]string{}
 
@@ -245,8 +237,6 @@ func ConfigureLazy(lazy bool) {
 // ProcessConstants is responsible for setting up the language features based on the JSON file that is stored in constants
 // Needs to be called at least once in order for anything to actually happen
 func ProcessConstants() {
-	languageDatabase = loadDatabase()
-
 	startTime := makeTimestampNano()
 	for name, value := range languageDatabase {
 		for _, ext := range value.Extensions {
@@ -267,9 +257,7 @@ func ProcessConstants() {
 		setupCountAs()
 	}
 
-	if Trace {
-		printTrace(fmt.Sprintf("nanoseconds build extension to language: %d", makeTimestampNano()-startTime))
-	}
+	printTraceF("nanoseconds build extension to language: %d", makeTimestampNano()-startTime)
 
 	// Configure COCOMO setting
 	_, ok := projectType[strings.ToLower(CocomoProjectType)]
@@ -303,13 +291,9 @@ func ProcessConstants() {
 			processLanguageFeature(name, value)
 		}
 
-		if Trace {
-			printTrace(fmt.Sprintf("milliseconds build language features: %d", makeTimestampMilli()-startTime))
-		}
+		printTraceF("milliseconds build language features: %d", makeTimestampMilli()-startTime)
 	} else {
-		if Trace {
-			printTrace("configured to lazy load language features")
-		}
+		printTrace("configured to lazy load language features")
 	}
 
 	// Fix for https://github.com/boyter/scc/issues/250
@@ -341,9 +325,7 @@ func setupCountAs() {
 				if strings.EqualFold(name, t[1]) {
 					ExtensionToLanguage[strings.ToLower(t[0])] = []string{name}
 					identified = true
-					if Debug {
-						printDebug(fmt.Sprintf("set to count extension: %s as language %s by language", t[0], name))
-					}
+					printDebugF("set to count extension: %s as language %s by language", t[0], name)
 				}
 			}
 
@@ -354,10 +336,7 @@ func setupCountAs() {
 
 				if ok {
 					ExtensionToLanguage[strings.ToLower(t[0])] = target
-
-					if Debug {
-						printDebug(fmt.Sprintf("set to count extension: %s as language %s by extension", t[0], target))
-					}
+					printDebugF("set to count extension: %s as language %s by extension", t[0], target)
 				}
 			}
 		}
@@ -389,9 +368,7 @@ func LoadLanguageFeature(loadName string) {
 
 	startTime := makeTimestampNano()
 	processLanguageFeature(loadName, value)
-	if Trace {
-		printTrace(fmt.Sprintf("nanoseconds to build language %s features: %d", loadName, makeTimestampNano()-startTime))
-	}
+	printTraceF("nanoseconds to build language %s features: %d", loadName, makeTimestampNano()-startTime)
 }
 
 func processLanguageFeature(name string, value Language) {
@@ -491,55 +468,26 @@ func processFlags() {
 		UlocMode = true
 	}
 
-	if Debug {
-		printDebug(fmt.Sprintf("Path Deny List: %v", PathDenyList))
-		printDebug(fmt.Sprintf("Sort By: %s", SortBy))
-		printDebug(fmt.Sprintf("White List: %v", AllowListExtensions))
-		printDebug(fmt.Sprintf("Files Output: %t", Files))
-		printDebug(fmt.Sprintf("Verbose: %t", Verbose))
-		printDebug(fmt.Sprintf("Duplicates Detection: %t", Duplicates))
-		printDebug(fmt.Sprintf("Complexity Calculation: %t", !Complexity))
-		printDebug(fmt.Sprintf("Wide: %t", More))
-		printDebug(fmt.Sprintf("Average Wage: %d", AverageWage))
-		printDebug(fmt.Sprintf("Cocomo: %t", !Cocomo))
-		printDebug(fmt.Sprintf("Minified/Generated Detection: %t/%t", Minified, Generated))
-		printDebug(fmt.Sprintf("Ignore Minified/Generated: %t/%t", IgnoreMinified, IgnoreGenerated))
-		printDebug(fmt.Sprintf("IncludeSymLinks: %t", IncludeSymLinks))
-		printDebug(fmt.Sprintf("Uloc: %t", UlocMode))
-		printDebug(fmt.Sprintf("Dryness: %t", Dryness))
-	}
-}
-
-func loadDatabase() map[string]Language {
-	var database map[string]Language
-	startTime := makeTimestampMilli()
-
-	gzData, err := base64.StdEncoding.DecodeString(languages)
-	if err != nil {
-		panic(fmt.Sprintf("failed to base64 decode languages: %v", err))
-	}
-	dataReader, err := gzip.NewReader(bytes.NewReader(gzData))
-	if err != nil {
-		panic(fmt.Sprintf("failed to create gzip reader: %v", err))
-	}
-
-	var json = jsoniter.ConfigCompatibleWithStandardLibrary
-	if err := json.NewDecoder(dataReader).Decode(&database); err != nil {
-		panic(fmt.Sprintf("languages json invalid: %v", err))
-	}
-
-	if Trace {
-		printTrace(fmt.Sprintf("milliseconds unmarshal: %d", makeTimestampMilli()-startTime))
-	}
-
-	return database
+	printDebugF("Path Deny List: %v", PathDenyList)
+	printDebugF("Sort By: %s", SortBy)
+	printDebugF("White List: %v", AllowListExtensions)
+	printDebugF("Files Output: %t", Files)
+	printDebugF("Verbose: %t", Verbose)
+	printDebugF("Duplicates Detection: %t", Duplicates)
+	printDebugF("Complexity Calculation: %t", !Complexity)
+	printDebugF("Wide: %t", More)
+	printDebugF("Average Wage: %d", AverageWage)
+	printDebugF("Cocomo: %t", !Cocomo)
+	printDebugF("Minified/Generated Detection: %t/%t", Minified, Generated)
+	printDebugF("Ignore Minified/Generated: %t/%t", IgnoreMinified, IgnoreGenerated)
+	printDebugF("IncludeSymLinks: %t", IncludeSymLinks)
+	printDebugF("Uloc: %t", UlocMode)
+	printDebugF("Dryness: %t", Dryness)
 }
 
 func printLanguages() {
-	database := loadDatabase()
-
-	names := make([]string, 0, len(database))
-	for key := range database {
+	names := make([]string, 0, len(languageDatabase))
+	for key := range languageDatabase {
 		names = append(names, key)
 	}
 
@@ -548,7 +496,7 @@ func printLanguages() {
 	})
 
 	for _, name := range names {
-		fmt.Printf("%s (%s)\n", name, strings.Join(append(database[name].Extensions, database[name].FileNames...), ","))
+		fmt.Printf("%s (%s)\n", name, strings.Join(append(languageDatabase[name].Extensions, languageDatabase[name].FileNames...), ","))
 	}
 }
 
@@ -594,11 +542,9 @@ func Process() {
 
 	SortBy = strings.ToLower(SortBy)
 
-	if Debug {
-		printDebug(fmt.Sprintf("NumCPU: %d", runtime.NumCPU()))
-		printDebug(fmt.Sprintf("SortBy: %s", SortBy))
-		printDebug(fmt.Sprintf("PathDenyList: %v", PathDenyList))
-	}
+	printDebugF("NumCPU: %d", runtime.NumCPU())
+	printDebugF("SortBy: %s", SortBy)
+	printDebugF("PathDenyList: %v", PathDenyList)
 
 	potentialFilesQueue := make(chan *gocodewalker.File, FileListQueueSize) // files that pass the .gitignore checks
 	fileListQueue := make(chan *FileJob, FileListQueueSize)                 // Files ready to be read from disk
