@@ -4,25 +4,33 @@ package main
 
 import (
 	"bytes"
-	"compress/gzip"
-	"encoding/base64"
-	"encoding/json"
+	_ "embed"
 	"fmt"
-	"io"
+	"go/format"
+	"maps"
 	"os"
+	"strconv"
 	"strings"
+	"text/template"
+
+	"github.com/boyter/scc/v3/processor"
+	jsoniter "github.com/json-iterator/go"
 )
 
 const constantsFile = "./processor/constants.go"
 
+var json = jsoniter.ConfigCompatibleWithStandardLibrary
+
+//go:embed languages.tmpl
+var langTemplate string
+
 // Reads all .json files in the current folder
 // and encodes them as strings literals in constants.go
 func generateConstants() error {
 	files, _ := os.ReadDir(".")
 	buf := &bytes.Buffer{}
 
-	// Open constants
-	_, _ = buf.WriteString("package processor\n\nconst (\n")
+	langs := map[string]processor.Language{}
 
 	for _, f := range files {
 		if strings.HasPrefix(f.Name(), "languages") && strings.HasSuffix(f.Name(), ".json") {
@@ -30,44 +38,46 @@ func generateConstants() error {
 			if err != nil {
 				return fmt.Errorf("failed to open file '%s': %v", f.Name(), err)
 			}
-			defer f.Close()
+			defer func(file *os.File) {
+				_ = file.Close()
+			}(f)
+
+			data := map[string]processor.Language{}
 
 			// validate the json by decoding into an empty struct
-			if err := json.NewDecoder(f).Decode(&struct{}{}); err != nil {
+			if err := json.NewDecoder(f).Decode(&data); err != nil {
 				return fmt.Errorf("failed to validate json in file '%s': %v", f.Name(), err)
 			}
 
-			// Reset position
-			if _, err := f.Seek(0, io.SeekStart); err != nil {
-				return fmt.Errorf("failed to reset file position '%s': %v", f.Name(), err)
-			}
-
-			// The constant variable name
-			_ = buf.WriteByte('\t')
-			_, _ = buf.WriteString(strings.TrimSuffix(f.Name(), ".json") + " = `")
-
-			enc := base64.NewEncoder(base64.StdEncoding, buf)
-			gz, _ := gzip.NewWriterLevel(enc, gzip.BestSpeed)
-			if _, err := io.Copy(gz, f); err != nil {
-				return fmt.Errorf("failed to encode file '%s': %v", f.Name(), err)
-			}
-			gz.Close()
-			enc.Close()
-
-			_, _ = buf.WriteString("`\n")
+			maps.Insert(langs, maps.All(data))
 		}
 	}
 
-	// Close out constants
-	_, _ = buf.WriteString(")\n")
+	t, err := template.New("codeGenerator").Funcs(template.FuncMap{
+		"quote": strconv.Quote,
+	}).Parse(langTemplate)
+	if err != nil {
+		return fmt.Errorf("failed to parse template file: %v", err)
+	}
+
+	if err := t.Execute(buf, langs); err != nil {
+		return fmt.Errorf("failed to execute template file: %v", err)
+	}
+
+	source, err := format.Source(buf.Bytes())
+	if err != nil {
+		return fmt.Errorf("failed to format code: %v", err)
+	}
 
 	out, err := os.OpenFile(constantsFile, os.O_WRONLY|os.O_CREATE|os.O_TRUNC, 0644)
 	if err != nil {
 		return fmt.Errorf("failed to open constants file: %v", err)
 	}
-	defer out.Close()
+	defer func(file *os.File) {
+		_ = file.Close()
+	}(out)
 
-	if _, err := io.Copy(out, buf); err != nil {
+	if _, err := out.Write(source); err != nil {
 		return fmt.Errorf("failed to write constants file %v", err)
 	}
 
